@@ -125,6 +125,10 @@ class MagicTodoMixin(TodoMixin, abc.ABC):
     def done(self: M) -> bool:  # noqa: D102
         return self.todo.done
 
+    @property
+    def epics(self: M) -> Tuple[str, ...]:  # noqa: D102
+        return self.todo.epics
+
     @property
     def metadata(self: M) -> Metadata:  # noqa: D102
         return self.todo.metadata
